pub fn migrate_old_log() -> boolExpand description
Migrate the old transaction.log (next to the binary) into the new
logs/ directory. Appends old entries to the new file, then renames
the old file to .migrated so it won’t be migrated again.
Returns true if an old log was found and handled.